﻿using System;
using System.Diagnostics;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.DesktopEdition;


namespace CSharpWinformsSamples
{
    public class ClickableMarkerOverlay : InMemoryMarkerOverlay
    {
        public event EventHandler Click;

        protected override GeoCollection<Marker> GetMarkersForDrawingCore(RectangleShape boundingBox)
        {
            var markers = base.GetMarkersForDrawingCore(boundingBox);
            foreach (var marker in markers)
            {
                marker.Click -= Click;
                marker.Click += Click;                
            }

            return markers;
        }

    }

    public class DisplayShapeMap : UserControl
    {
        public DisplayShapeMap()
        {
            InitializeComponent();
        }

        private void DisplayMap_Load(object sender, EventArgs e)
        {
            winformsMap1.MapUnit = GeographyUnit.DecimalDegree;
            winformsMap1.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean);
            winformsMap1.CurrentExtent = new RectangleShape(-139.2, 92.4, 120.9, -93.2);

            ClickableMarkerOverlay viewLinkMarkerOverlay = new ClickableMarkerOverlay() { Name = "test", MapControl = winformsMap1 };            
            viewLinkMarkerOverlay.ZoomLevelSet.ZoomLevel01.DefaultPointMarkerStyle.Image = Properties.Resources.ThinkGeoLogo;
            viewLinkMarkerOverlay.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            winformsMap1.Overlays.Add(viewLinkMarkerOverlay.Name, viewLinkMarkerOverlay);

            Feature vlFeature = new Feature(new PointShape(10, 10));
            viewLinkMarkerOverlay.FeatureSource.BeginTransaction();
            viewLinkMarkerOverlay.FeatureSource.AddFeature(vlFeature);
            viewLinkMarkerOverlay.FeatureSource.CommitTransaction();
            winformsMap1.Overlays.MoveToTop(viewLinkMarkerOverlay.Name);
            

            winformsMap1.MapClick += WinformsMap1_MapClick;
            winformsMap1.MouseClick += WinformsMap1_MouseClick;
            winformsMap1.MouseDown += WinformsMap1_MouseDown;
            winformsMap1.MouseUp += WinformsMap1_MouseUp;
            winformsMap1.MouseMove += WinformsMap1_MouseMove;

            viewLinkMarkerOverlay.Click += ViewLinkMarkerOverlay_Click;

            winformsMap1.Refresh();
        }

        private void ViewLinkMarkerOverlay_Click(object sender, EventArgs e)
        {
            Debug.WriteLine("Marker clicked!!!!");
        }

        private void WinformsMap1_MouseMove(object sender, MouseEventArgs e)
        {
            Debug.WriteLine("MouseMove");
        }

        private void WinformsMap1_MouseUp(object sender, MouseEventArgs e)
        {
            Debug.WriteLine("MouseUp");
        }

        private void WinformsMap1_MouseDown(object sender, MouseEventArgs e)
        {
            Debug.WriteLine("MouseDown");
        }

        private void WinformsMap1_MouseClick(object sender, MouseEventArgs e)
        {
            Debug.WriteLine("MouseClick");
        }

        private void WinformsMap1_MapClick(object sender, MapClickWinformsMapEventArgs e)
        {
            Debug.WriteLine("MapClick");            
        }

        private WinformsMap winformsMap1;

        #region Component Designer generated code

        private System.ComponentModel.IContainer components = null;

        /// <summary> 
        /// Clean up any resources being used.
        /// </summary>
        /// <param name="disposing">true if managed resources should be disposed; otherwise, false.</param>
        protected override void Dispose(bool disposing)
        {
            if (disposing && (components != null))
            {
                components.Dispose();
            }
            base.Dispose(disposing);
        }

        /// <summary> 
        /// Required method for Designer support - do not modify 
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
            ThinkGeo.MapSuite.DesktopEdition.EditInteractiveOverlay editInteractiveOverlay1 = new ThinkGeo.MapSuite.DesktopEdition.EditInteractiveOverlay();
            ThinkGeo.MapSuite.DesktopEdition.ExtentInteractiveOverlay extentInteractiveOverlay1 = new ThinkGeo.MapSuite.DesktopEdition.ExtentInteractiveOverlay();
            ThinkGeo.MapSuite.DesktopEdition.TrackInteractiveOverlay trackInteractiveOverlay1 = new ThinkGeo.MapSuite.DesktopEdition.TrackInteractiveOverlay();
            this.winformsMap1 = new ThinkGeo.MapSuite.DesktopEdition.WinformsMap();
            this.SuspendLayout();
            // 
            // winformsMap1
            // 
            this.winformsMap1.BackColor = System.Drawing.Color.Gray;
            this.winformsMap1.Dock = System.Windows.Forms.DockStyle.Fill;
            editInteractiveOverlay1.IsVisible = true;
            editInteractiveOverlay1.Name = null;
            this.winformsMap1.EditOverlay = editInteractiveOverlay1;
            extentInteractiveOverlay1.IsVisible = true;
            extentInteractiveOverlay1.Name = null;
            this.winformsMap1.ExtentOverlay = extentInteractiveOverlay1;
            this.winformsMap1.Location = new System.Drawing.Point(0, 0);
            this.winformsMap1.MapUnit = ThinkGeo.MapSuite.Core.GeographyUnit.DecimalDegree;
            this.winformsMap1.MaximumScale = 80000000000000;
            this.winformsMap1.MinimumScale = 200;
            this.winformsMap1.Name = "winformsMap1";
            this.winformsMap1.MapResizeMode = ThinkGeo.MapSuite.Core.MapResizeMode.PreserveScale;
            this.winformsMap1.Size = new System.Drawing.Size(740, 528);
            this.winformsMap1.TabIndex = 0;
            this.winformsMap1.Text = "winformsMap1";
            trackInteractiveOverlay1.IsVisible = true;
            trackInteractiveOverlay1.Name = null;
            trackInteractiveOverlay1.TrackMode = ThinkGeo.MapSuite.DesktopEdition.TrackMode.None;
            this.winformsMap1.TrackOverlay = trackInteractiveOverlay1;
            this.winformsMap1.ZoomLevelSnapping = ThinkGeo.MapSuite.DesktopEdition.ZoomLevelSnappingMode.Default;
            this.winformsMap1.ExtentOverlay.ZoomPercentage = 40;
            // 
            // DisplayShapeMap
            // 
            this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 13F);
            this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
            this.Controls.Add(this.winformsMap1);
            this.Name = "DisplayShapeMap";
            this.Size = new System.Drawing.Size(740, 528);
            this.Load += new System.EventHandler(this.DisplayMap_Load);
            this.ResumeLayout(false);

        }

        #endregion
    }
}
